checks

package
v0.17.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 7, 2022 License: MIT Imports: 2 Imported by: 0

Documentation

Overview

Package checks provides utilities to check for certain properties of a sequence.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GcContent added in v0.13.0

func GcContent(sequence string) float64

GcContent checks the GcContent of a given sequence.

func IsPalindromic

func IsPalindromic(sequence string) bool

IsPalindromic accepts a sequence of even length and returns if it is palindromic. More here - https://en.wikipedia.org/wiki/Palindromic_sequence

Types

This section is empty.

Jump to